@@ -16,7 +16,7 @@ use		Dancer2::Plugin;
 use		Storable;
 use		strict;
 use		warnings;
-our		$VERSION = '3.100';
+our		$VERSION = '3.101';
 
 if ($^O=~/(?i)MSWin/) {warn "Sorry this operating system is not supported (and it will never be)\n"; exit 1}
 
@@ -66,7 +66,7 @@ $plugin->{app}->{config}->{plugins}->{WebService}->{'Default format'}		//= 'json
 $plugin->{app}->{config}->{plugins}->{WebService}->{'Session idle timout'}	//= 3600;
 
 unless( __MKDIR($plugin->dir_session) ) {warn 'Could not create the session directory '.$plugin->dir_session." because $!\n"; exit 1}
-(my $module_dir =__FILE__) =~s/\/(?>[^\/]+)$//;
+(my $module_dir =__FILE__) =~s|/[^/]+$||;
 unless (-d $module_dir) {warn "Sorry could not find the Dancer2::Plugin::WebService installation directory\n"; exit 1}
 
 print STDOUT "\nWebService version   : $VERSION\n";
@@ -129,8 +129,8 @@ delete $plugin->config->{'Authentication methods'};
 	last
 	}
 
-print STDOUT 'Authorization method : ', $plugin->auth_method	,"\n";
-print STDOUT 'Authorization command: ', $plugin->auth_command	,"\n\n";
+print STDOUT 'Authorization method : ',$plugin->auth_method	,"\n";
+print STDOUT 'Authorization command: ',$plugin->auth_command,"\n\n";
 
 # Clear expired stored sessions
 $_ = $plugin->dir_session;
@@ -273,7 +273,7 @@ closedir __SESSIONDIR;
 
 				$plugin->reply(
 				Application			=> $plugin->{app}->{name},			
-				Os					=> eval{ local $_ = undef; local $/ = undef; open __F, -f '/etc/redhat-release' ? '/etc/redhat-release' : '/etc/issue'; if (fileno __F) { ($_= <__F>)=~s/\s*$//s; $_ = join ' ', split /\v/, $_ } close __F; $_ // $^O },
+				Os					=> eval{ local $_ = undef; local $/ = undef; open __F, -f '/etc/redhat-release' ? '/etc/redhat-release' : '/etc/issue'; if (fileno __F) { ($_= <__F>)=~s/\s*$//s; $_ = join ' ', split /v/, $_ } close __F; $_ // $^O },
 				Bind				=> sub { $_={}; @{$_}{qw/Address Port/} = split /:/, $app->request->host; $_ }->(),
 				'WebService uptime'	=> time - $^T,
 				Epoch				=> time,
@@ -972,7 +972,7 @@ Dancer2::Plugin::WebService - Rapid creation of RESTful Web Services with sessio
 
 =head1 VERSION
 
-version 3.100
+version 3.101
 
 =head1 SYNOPSIS
 
@@ -1056,7 +1056,7 @@ Dancer2::Plugin::WebService - Rapid creation of RESTful Web Services with login/
 
 =head1 VERSION
 
-version 3.100
+version 3.101
 
 =head1 POLYMORPHISM
 
